#
# spec file for package python-enaml
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-enaml
Version:        0.17.0
Release:        1.3
# Source code is under BSD but images are under different licenses
# and details are inside image_LICENSE.txt
Summary:        Declarative DSL for building rich user interfaces in Python
License:        BSD-3-Clause AND LGPL-2.1-only
URL:            https://github.com/nucleic/enaml
Source:         https://files.pythonhosted.org/packages/source/e/enaml/enaml-%{version}.tar.gz
BuildRequires:  %{python_module cppy >= 1.2.0}
BuildRequires:  %{python_module devel >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 61.2}
BuildRequires:  %{python_module setuptools_scm >= 3.4.3}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-atom >= 0.8.0
Requires:       python-bytecode >= 0.13.0
Requires:       python-kiwisolver >= 1.2.0
Requires:       python-ply
# SECTION The Qt variants are optional variants in the python metadata, but probably either one is required and they all require QtPy
Requires:       python-QtPy >= 2.1.0
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
# pyside is python3 only, PyQt5 (-qt5) and PyQt6 are multiflavored
Requires:       (python-qt5 or python-PyQt6 >= 6.3.1 or python3-pyside2 or python3-pyside6 >= 6.2.3)
%else
Requires:       (python-qt5 or python-PyQt6 >= 6.3.1)
%endif
# /SECTION
Requires(post): update-alternatives
Requires(postun):update-alternatives
# SECTION test requirements
BuildRequires:  %{python_module QtPy >= 2.1.0}
BuildRequires:  %{python_module atom >= 0.8.0}
BuildRequires:  %{python_module bytecode >= 0.13.0}
BuildRequires:  %{python_module kiwisolver >= 1.2.0}
BuildRequires:  %{python_module pegen}
BuildRequires:  %{python_module ply}
BuildRequires:  %{python_module pytest-qt}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module qt5}
BuildRequires:  xauth
BuildRequires:  xorg-x11-fonts
# /SECTION
%python_subpackages

%description
Enaml is a programming language and framework for creating
professional quality user interfaces with minimal effort.
Enaml combines a domain specific declarative language with
a constraints based layout system to allow users to easily
define rich UIs with complex and flexible layouts. Enaml
applications can be run on any platform which supports
Python and Qt.

%prep
%setup -q -n enaml-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_clone -a %{buildroot}%{_bindir}/enaml-compileall
%python_clone -a %{buildroot}%{_bindir}/enaml-run

%check
# use the builddir instead of buildroot in order to avoid
# packaging of unreproducible files generated during tests
# https://github.com/nucleic/enaml/issues/397
%python_expand cp -r %{buildroot}%{$python_sitearch} build/testlib
export PYTHONPATH=$PWD/build/testlib
# See the skipif mark of the tests: 'Skip on linux CI where setting up a windows manager is a nightmare'
donttest="test_focus_tracking or test_focus_traversal"
%pytest_arch tests -k "not ($donttest)"

%post
%python_install_alternative enaml-compileall enaml-run

%postun
%python_uninstall_alternative enaml-compileall

%files %{python_files}
%doc README.rst releasenotes.rst
%license LICENSE
%python_alternative %{_bindir}/enaml-compileall
%python_alternative %{_bindir}/enaml-run
%{python_sitearch}/enaml
%{python_sitearch}/enaml-%{version}*-info

%changelog
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 0.17.0:
  * support for Python 3.12 PR #535 Python 3.12 is only tested
    with Qt6 All syntactic features of Python 3.12 are supported
    and catching error groups is now supported.
  * fix a bug in Enaml parser that was not showing proper
    location of syntax and indentation errors in tracebacks when
    the error was in an Enaml file. PR #530
* Sun May  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.16.1:
  * fix typo causing a crash in dock area
  * fix a multi-inheritance issue with pyside6 which affected the
    dock area
* Wed Mar  8 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.16.0:
  * add support for Python 3.11+ PR #514
  * fix several issues related to PySide6 PR #513
  * switch to use pegen to generate the parser PR #474
  * implement hash and eq for decl functions PR #517
- Add pegen to BuildRequires.
* Thu Dec 15 2022 Ben Greiner <code@bnavigator.de>
- Update tp version 0.15.2
  * fix position of popup view when multiple displays are used PR
    [#500]
  * reimplement DockArea.initialize instead of shadowing the
    initialized member. PR #502
  * require qtpy>=2.1 far Qt backends version PR #501
  * qt: use QEvent.Type to coerce new registered event type with
    all bindings. PR #497 This requires PyQt 6.3.1 to work and
    allow to eliminate a deprecation warning.
  * fix loading of dock area guide images. PR #503
- Release 0.15.1
  * bump qtpy minimal required version for Qt6 PR #490
  * fix drag and drop support under Qt6 PR #491
  * fix date and time conversion under Qt6 PR #486
  * fix handling of mouse press event by popup views PR #486
  * fix flow widget size computation to only use integer (fixes
    Qt6) PR #492
  * add new extra requirements to ease use of widgets with extra
    dependencies PR #495
- Release 0.15.0
  * make install PEP 517 compliant and use a PEP 621 compliant
    pyproject.toml PR #485
  * add support for PyQt6 and Pyside6 PR #475
  * fix last occurrences of passing float instead of int to PyQt PR
    [#481]
  * add new declarative @observe which ignores 'create' and
    'container' events by default PR #479
  * use atom builtin filtering mechanism to avoid refreshing the
    declarative engine on 'create' and 'container' event PR # 479
- Release 0.14.1
  * fixes a bug in code generation for Python 3.10 PR #476
  * fixes several bugs in corner cases of the Qt dock area PR #469
  * add python fstring scintilla tokens PR #470
  * address PyQt deprecation of accepting float values for pixel
    dimensions PR #471
* Mon Dec  6 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.14.0
  * use enum.IntEnum/IntFlag instead of atom.IntEnum PR #453
  * fix operator bindings in template instances PR #445
  * fix FlowLayout error with FlowItems that have non-zero stretch or ortho_stretch PR #448
  * add support for styling notebook tabs PR #452
  * drop official support for Python 3.6 and add minimal support for Python 3.10
    As with earlier Python version, support for 3.10 is currently limited to running on
    Python 3.10 excluding any features that were added in Python 3.10
- Stop building on Python 3.6 which is no longer supported
- Switch back to using upstream tarball URL in Source field
- Update BuildRequires and Requires from setup.py
* Wed Aug 11 2021 mcepl@cepl.eu
- Update to version 0.13.0+git.1627388100.6864e8bc (so as to make
  the test suite pass with pytest-qt > 3):
  * Add release notes entry
  * Flow Layout sort fix for stretch or ortho_stretch > 0
  * cis: test on python 3.10.b.4
  * tests: fix missing imports
  * cis: do not run with -W error due to ipykernel and add missed skip for focus
  * cis: skip focus tests on linux (ci) and run extended tests on 3.9 rather than 3.8
  * cis: bump to python 3.10 beta 3 and skip linux for the time being
  * tests: fix warnings and try another window manager
* Wed Aug 11 2021 Matej Cepl <mcepl@suse.com>
- Switching off temporarily the test suite
  (gh#nucleic/enaml#449).
* Wed Apr 28 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.13
  * fix Python 3.9 only syntax issue PR #443
  * make app editor more resilient to errors PR #440
  * fixes to vim syntax highlighting PR #439
  * fix documentation of ScrollArea example PR #438
  * add extra_requires to provide an easy way to install qt
    bindings when relevant PR # 434
  * add support for explicit Qt app name PR #430 Allows setting
    the WM_CLASS property for X11 (Linux) apps.
- Release 0.12.0
  * add support for Python 3.9 PR #424
  * add support for PySide2 and fix Qt deprecation PR #423
  * add support for subscription block PR #348 Subscription blocks
    allow to write right to left synchronization logic over
    multiple lines and using statements. The assigned value is the
    value returned from the block.
  * add support for Python 3.8 only syntax PR #422 This covers:
    the walrus operator (:=), and the use of * in return and yields
- Don't alter the buildroot in %%check
* Sun Jul 12 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Dont ship unreproducible cache files to make package build reproducible
* Thu Jul  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.11.2
  * fix reference counting in declarative function PR #417
  * fix signaling/weakmethod/callableref that were broken since 0.10.0 PR #416
  * coerce iterator iterables of loopers to tuple so refresh works properly PR #414
* Thu Apr  9 2020 pgajdos@suse.com
- version update to 0.11.0
  * 0.11.0 - 05/04/2020
    add support for Python 3.8 (not Python 3.8 only syntax) PR #391
    enforce conversion of float to int at the Qt boudary PR #391
    replace byteplay by bytecode PR #391
    add get method to DynamicScope PR #394
    properly set the attributes of imported module PR #398
    qt: fix alerts on tabbed DockItem PR #396
    qt: avoid going higher than the dock area when looking for a DockTabWidget among the parents of a QDockContainer PR #386
    properly report SyntaxError in f strings PR #378
    add support for using attributes (. access) when specifying attr types PR #359
    limit support to Python 3 PR #349
    use cppy for the Python/C interface PR #349
    qt: add missing brackets to widget.focusPolicy within qt_widget.py/QtWidget.tab_focus_request() PR #403
    qt: fix return value of QtWidget.tab_focus_request() PR #404
  * 0.10.4 - 18/09/2019
    fix a bug in the parser preventing the use of raise from under Python 3 PR #364
    add a ButtonGroup widget and a group attribute on all buttons to allow to group buttons belonging to different containers. PR #346
    fix an issue in ImageView when the image is None PR #361
    add a sync_time attribute to Field to control the refresh rate when using the 'auto_sync' trigger mode. PR #353
    multiple improvement of the documentation PR #341 #345 #350
    add a new example about layout PR #343
    fix issue where fields with a validator would lose their original stylesheet when the error state of the validator is cleared. PR #365
    fix Looper's loop_index becoming invalid when items are reordered #357 via PR #358
* Wed Feb  5 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.10.4
  * Fix issue with validator fields, where clearing the error
    state does not restore the original stylesheet
  * Update Looper loop index when items are reordered
  * widgets: add logic to track the members of a ButtonGroup
  * Add button group widget
  * qt: handle the absence of a pixmap when computing the aspect_ratio
  * widgets: add sync_time attribute to Field
* Thu Jul 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.10.3
  * implement import hooks using Python 3 interface
  * make enaml-run exit immediately when pressing ^c
  * add support for f-strings in enaml files on supported Python versions
  * add support for declarative async function
  * add a enaml-compileallcommand to generate pyc and enamlc files
  * fix the tp_name value of all C extensions
  * add pickle support for enaml's Color
  * add support for tiling and cascading to MdiArea
  * fix issue # 174 (MdiWindow not automatically shown when added)
  * add minimal workbench documentation
  * add support for font-stretch
  * remove dependency on future to reduce import time
  * add constraints to enforce image aspect ratio in ImageView
  * improvements to the scintilla widget and live editor
  * Multiple improvements to the documentation
* Wed May 16 2018 toddrme2178@gmail.com
- Update to 0.10.2
  * fix import of QScintilla under PyQt5 PR #230
  * add support for importing enaml files from zip archives #232
  * fix menu item ordering under Python 3 #233
  * fix repr of declarative function objects #235
  * properly reset layout_container member in qt backend after a widget has been
    reparented #240
  * fix calls to explicit_warn which could lead to global vars corruption #247
  * add a text align member to Field to control text alignment #249
  * fix the parsing rules for function definitions #252
  * several improvements to the handling of comprehensions and lambdas #242 #245
- Update to 0.10.1
  * fix mistake in setup.py file preventing conda package building
- Update to 0.10.0
  * add support for Qt5 (based on QtPy) PR #228
  * add support for Python 3 (3.3, 3.4, 3.5, 3.6) (f-strings are not supported) PR #227
  * refactor the parser to be based on classes PR #227
  * move every parser/lexer related module in the parser package PR #227
  * support for dict and set comprehensions in enaml files PR #227
- Implement single-spec version
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 0.9.8
  - Add drag and drop support. 56a2127e714c_
  - Remove the Wx backend and free the people from their misery. bab233ff9782_
- Update to 0.9.7
  - Add an IPythonConsole widget.
  - Add support for widgets in tool bars and menus.
  - Add a ToolButton widget.
  - Removed the 'focus_policy' attribute.
  - Removed the 'show_focus_rect' attribute.
  - Fix bugs #122, #123, #124, #131, #145
- Update to 0.9.6
  - Add a declarative function syntax to the grammar.
  - Add a comprehensive focus API. 1090b3f35a9c_
- Update to 0.9.5
  - Allow pressing escape while dragging a floating dock window. e732d2bb3c6c_
  - Fix line ending issues in live editor on old versions of OSX (thanks to JF). 0a54944728ae_
- Update to 0.9.4
  - Allow enamldef objects to be properly pickled. db99d02fa377_
- Update to 0.9.3
  - Return the value of the command handler from CorePlugin.invoke_command. 5322bd1d2a67_
  - Automatically request relayout when widget visibility changes. 5d24f8ab13cb_
  - Add knobs for controlling Form row and column spacing. cdb747d8d1fa_
  - Add VGroup and HGroup convenience layout factories. aed5ddd623d1_
  - Add a 'factory' layout helper. 41480f2694d2_
- Update to 0.9.2
  - Update the layout (if needed) when changing fonts.
  - Minor code cleanup and documentation updates.
- Update to 0.9.1
  - Add the workbench plugin framework. 2ab09c6782b4_
  - Fix idiosyncrasies in layout. 5a9f529671dd_
  - Add a VTKCanvas control. b04262195c27_
  - Add ability to veto a window close. bbd9aa1be9f2_
  - Fix issues #64 #119 #120 #128 #129
- Update to 0.9.0
  - Fix issue #78. f0d1fc7da0d7_
  - Update the layout engine to use the Kiwi solver. d41729049f63_
- Update to 0.8.9
  - Add ability to query window minimized/maximized state. 713feb85952a_
  - Implement 'always_on_top' window flag. 3ac3e6955579_
  - A handful of bug fixes.
- Update to 0.8.8
  - Add a task dialog mini-framework and a MessageBox stlib component. 5583808f293a_
- Update to 0.8.7
  - Add an alerting api for dock items in a dock area. ba766d773090_
- Update to 0.8.6
  - Add 'limit_width' and 'limit_height' virtual constraints. 8722be90844e_
- Update to 0.8.5
  - Add support for style sheets to the DockArea. 5e38c591ad55_
- Update to 0.8.4
  - Add a size hint mode switch to Notebook and Stack. 330c7a337c32d_
- Update to 0.8.3
  - Add support for style sheets. 77e2a0afbd56_
  - Fix a bug with a null widget and the notebook selected tab. 64cfe8789838_
- Update to 0.8.2
  - Add a DynamicTemplate declarative object. ede76a778a86_
  - Add 'window' mode to PopupView. f37263fd7b7d_
  - Add 'selected_tab' attribute to the Notebook. 45ca092e7222_
  - Overhaul of the docs and doc build system.
  - Various bug fixes and performance improvements.
- Update to 0.8.1
  - Update the PopupView to automatically reposition on-screen. 3225683f9411_
  - Minor bug fixes.
  - Added an ImageView example.
- Update to 0.8.0
  - Added templates to the language.
  - Added aliases to the language.
  - Removed the compatibility code scheduled for removal.
  - Added a completely new declarative expression engine.
- Update to 0.7.20
  - Bugfix area layout traversal. 308164fd5134_
  - Allow alpha hex colors. d9605cc55bb5_
  - Add a declarative Timer object. 13259258e6fd_
  - Added a Scintilla widget.
  - Added the applib sub-package.
  - Added live editor components to the applib.
  - Added an 'auto_sync' submit trigger to Field. 1926cde5e64b_
- Update to 0.7.19
  - Added dock layout ops for extending/retracting from dock bars. 00ee34a102f_
  - Added methods for manipulating window geometry. bebba0a82fa_
- Update to 0.7.18
  - Production release of dock area toolbars.
  - Updates to dock layout specification with compatibility env setting.
  - Resizable slide-out dock bar items.
  - Pin buttons on dock items.
  - Improved procedural dock layout modification api.
  - Added a base Frame class which supplies borders for subclasses. d1316f40248_
  - Fixed container ref-cycle issue on widget destruction. 03a5e53038f_
- Update to 0.7.17
  - Added easier to use operator hooks. 2aaf3c96fc8_
  - Added support for PySide. 0d18a21754e_
  - Add cursor anchor mode to PopupView. 74ddd47197e_
  - Initial feedback release of dock area toolbars.
- Update to 0.7.16
  - Add a more useful file dialog as FileDialogEx. 390868cccb_
  - Add a color selection dialog as ColorDialog. d722a876e9_
  - Persist the linked state of floating dock items in a saved layout. adc9dec8db_
  - Add a right click event to the dock item title bar. 812e97aebcf_
  - Make the dock item title user editable. 54b68881529_
  - Make the visibility of the dock item title bar configurable. 54b68881529_
  - Toggle the maximized state of a dock item on title bar double click. 4ffe9d6b68e_
  - Add a RawWidget widget to easily embed external widgets into Enaml. e9d25a29e77_
- Update to 0.7.15
  - Fix a bug in parsing elif blocks. e25363b005_
- Update to 0.7.14
  - Make the translucent background of PopupView configurable. 0731314117_
  - Add a 'live_drag' flag to the DockArea. 0cd6889b2c_
- Update to 0.7.13
  - Feature improvements and fixes to snappable dock frames. 693a6f363a_
  - Add a 'link_activated' event to the Label widget. 269b386639_
- Update to 0.7.12
  - Make floating dock windows snappable and linkable. de3ced381e_
- Update to 0.7.11
  - Claw back the direct exposure of the Qt stylesheets. 947760ebcd_
- Update to 0.7.10
  - Expose the Qt stylesheet directly for the dock area. 5877335bcf_
  - Add the ability to style the various dock area buttons. 5877335bcf_
- Update to 0.7.9
  - Make the close button on dock items configurable. d839fb0c2b_
  - Expose a public api for manipulating the dock layout. e269adbdb2_
  - Expose user configurable dock area styles. 4c05d5953f_
- Update to 0.7.8
  - Add support for maximizing a docked item within a DockArea. a051862ce5_
  - Update the popup view to use a 45 degree angled arrow. f3edc88fe1_
  - Miscellaneous updates and bug fixes to the DockArea.
- Update to 0.7.7
  - Add support for floating "dock rafts" in the DockArea. 402330dcaf_
  - Add a PopupView widget to support transparent popups and growl-style notifications. a5117121bf_
- Update to 0.7.6
  - Add an advanced DockArea widget. 3ed122b110_
  - Add popup() functionality to the Menu widget. 5363a56f33_
- Update to 0.7.5
  - Fix a bug in the Wx main window implementation. 39f6baee49_
- Update to 0.7.4
  - Add border support for Container on the Qt backend. 505662d5f1_
  - Workaround a logic bug in Wx's handling of modal windows. 56a1e00112_
  - Workaround a Wx segfault during window destruction. a8525788c9_
- Update to 0.7.3
  - Added support for adding/removing models in a ViewTable. 5bc1809340_
  - Added an ObjectCombo control which is a more flexible combo box. 51f3a3c6d3_
  - Emit useful error messages when a backend does not implement a control. b264b3b927_
- Update to 0.7.2
  - Added first real cut at a model-viewer grid-based control. de0d8e35ae_
  - Fix a bug in size hinting during complex relayouts. 963cee88d0_
  - Added hooks for proxy-specific customization. 3e045dfb18_
- Update to 0.7.1
  - Updated compiler infrastructure to produce more extensible parse trees.
  - Various bug fixes.
- Update to 0.7.0
  - First release under new nucleic org.
  - Rewrite of entire framework to sit on top of Atom instead of Traits.
  - Vastly improved backend architecture.
  - Improved compile-time operator binding.
- Update to 0.6.8
  - Added ability to change the Z order of a window and a flag to make it stay on top. d6f618101f_
  - Added a multiline text entry widget. dde4bd3409_
  - Bugfix when ImageView is used in a ScrollArea. 67133d3fec_
- Update to 0.6.7
  - Added a `root_object()` method on the `Object` class which returns the root of the object tree. d9b4830963_
  - Properly handle window modality on the Qt backend. 28f2433814_
  - Add a `destroy_on_close` flag to the `Window` class. 2a63e8cefd_
  - Prevent Wx from destroying top-level windows by default. 8e298e768e_
  - Add support for adding windows to a session at run-time. c090c0fad6_
  - Fix the lifetime bug with the `FileDialog`. 8e354de858_
- Update to 0.6.6
  - Fix the broken unittests and make them Python 2.6 safe. 2c1d7f01d_
- Update to 0.6.5
  - Add a stretch factor to the Splitter widget. c2272cf1ef_
  - Fix bugs in the Wx splitter implementation. dfa542ba3d_
- Update to 0.6.4
  - Add support for icons on notebook pages on the Qt backend. b6426b7ae9_
  - Add support for popup menus in the Wx backend (Qt is already supported). 153f3124b2_
  - Add simpler way of building the optional C++ extensions. 4eebd59ae5_
  - Update enaml-run to play nice with ETS_TOOLKIT. f864975a87_
- Update to 0.6.3
  - Fix critical bug related to traits Disallow and the `attr` keyword. 25755e2bbd_
- Update to 0.6.2
  - Fix critical bug for broken dynamic scoping. a788869ab0_
- Update to 0.6.1
  - Fix critical bug in compiler and expression objects. dfb6f648a1_
- Update to 0.6.0
  - Add Icon and Image support using a lazy loading resource sub-framework. 77d5ca3b01_
  - Add a traitsui support via the TraitsItem widget (care of Steven Silvester). 9cb9126da1_
  - Add matplotlib support via the MPLCanvas widget (care of Steven Silvester). eaa6294566_
  - Updated Session api which is more intuitive and easier to use.
  - Updated Object api which is more intuitive and easier to use.
  - Object lifecycle reflected in a `state` attribute.
  - Huge reduction in memory usage when creating large numbers of objects.
  - Huge reduction in time to create large numbers of objects.
  - New widget registry make it easier to register custom widgets. cc791a52d7_
  - Better and faster code analysis via code tracers. 4eceb09f70_
  - Fix a parser bug related to relative imports. 3e43e73e90_
  - Various other tweaks, bugfixes, and api cleanup.
- Update to 0.5.1
  - Fix a method naming bug in QSingleWidgetLayout. 7a4c9de7e6_
  - Fix a test height computation bug in QFlowLayout. a962d2ae78_
  - Invalidate the QFlowLayout on layout request. 1e91a54245_
  - Dispatch child events immediately when possible. e869f7124f_
  - Destroy child widgets after the children change event is emitted. c695ae35ee_
  - Add a preliminary WebView widget. 27faa381dc_
- Update to 0.5.0
  - Merge the feature-async branch into mainline. f86dad8f6e_
  - First release with release notes. 8dbed4b9cd_
- Update source to pypi url.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Tue May 22 2012 toddrme2178@gmail.com
- Initial spec file
